#
# spec file for package libsmi
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libsmi
Version:        0.4.8
Release:        22.5
Url:            http://www.ibr.cs.tu-bs.de/projects/libsmi
Summary:        A Library to Access SMI MIB Information
License:        MIT
Group:          System/Libraries
Source:         https://www.ibr.cs.tu-bs.de/projects/%{name}/download/%{name}-%{version}.tar.gz
Patch0:         libsmi-0.4.8-parser.patch
Patch1:         libsmi-0.4.8-gnu-source.patch
Patch2:         libsmi-CVE-2010-2891.patch
Patch3:         libsmi-flex.patch
Patch4:         libsmi-bison-3.0.patch
Patch5:         libsmi-exports.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libtool
BuildRequires:  pkg-config

%description
The purpose of libsmi is to

* Give network management applications a concise programmer-friendly
   interface to access MIB module information

* Separate the knowledge on SMI from the main parts of management
   applications

* Allow addition of new kinds of MIB repositories without the need to
adapt applications that make use of libsmi

%package devel
Summary:        Libsmi Header Files And Static Libraries
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       glibc-devel

%package -n libsmi2
Summary:        Libsmi Shared Libraries
Group:          System/Libraries  
Requires:       %{name} = %{version}

%description -n libsmi2
The purpose of libsmi is to

* Give network management applications a concise programmer-friendly
   interface to access MIB module information

* Separate the knowledge on SMI from the main parts of management
   applications

* Allow addition of new kinds of MIB repositories without the need to
adapt applications that make use of libsmi

%description devel
This package contains the header files and static libraries of package
libsmi.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2
%if 0%{?suse_version} > 1220 && 0%{?suse_version} < 1321
%patch3 -p1
%endif
%patch4 -p1
%patch5 -p1

%build
autoreconf --force --install
%configure --disable-static \
           --with-pic --enable-smi \
	       --enable-sming \
	       --with-mibdir=%{_datadir}/mibs
# Parallel build disabled
make #%{?_smp_mflags}

%install
make install DESTDIR=%buildroot
rm -f %{buildroot}%{_libdir}/*.la

%check
make check || cat test/test-suite.log && exit 0

%post -n libsmi2 -p /sbin/ldconfig

%postun -n libsmi2 -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc ANNOUNCE COPYING ChangeLog README THANKS TODO doc/*.txt
%doc %{_mandir}/man?/*
%{_bindir}/*
%{_datadir}/mibs
%{_datadir}/pibs

%files -n libsmi2
%defattr(-, root, root)
%{_libdir}/libsmi.so.*

%files devel
%defattr(-, root, root)
%{_includedir}/*
%{_libdir}/libsmi.so
%{_libdir}/pkgconfig/libsmi.pc
%{_datadir}/aclocal/libsmi.m4

%changelog
* Fri Feb 27 2015 dimstar@opensuse.org
- No longer apply libsmi-flex.patch on openSUSE Tumbleweed (> 13.2).
* Tue Jan 27 2015 crrodriguez@opensuse.org
- fix missing pkgconfig buildRequires
- Run make check but ignore failures.
* Tue Jan 27 2015 crrodriguez@opensuse.org
- libsmi-exports.patch: Export only the symbols of the public
  API, specially hide and avoid using internal
  vasprintf and asnprintf implementations that will
  name-clash with the C library.
* Wed Jan 21 2015 dimstar@opensuse.org
- Disable parallel build to reduce random build failures.
* Tue Jan 20 2015 dimstar@opensuse.org
- Add libsmi-bison-3.0.patch: Fix build with bison 3.0.
* Mon Apr 15 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Tue Nov 13 2012 idonmez@suse.com
- Add libsmi-flex.patch: yyleng should be type of size_t
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Nov 11 2010 nadvornik@novell.com
- fixed buffer overflow CVE-2010-2891 (bnc#649867)
* Mon Mar 29 2010 boris@steki.net
- Created subpackage libsmi2 to make rpmlint happy
* Sat Mar 27 2010 boris@steki.net
- update to 0.4.8
  * test/*: updated a couple of checks.
  * tools/*: fixed a couple of minor compiler warnings.
  * new MIBs
  * tools/Makefile.am: added missing files to the distribution.
- patch for cast correction in parser-sming.y
- require of bison and flex in spec so build will rebuild parsers
* Fri Jan  9 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- remove deprecated run_ldconfig usage
- define _GNU_SOURCE where needed
* Wed Oct 18 2006 mjancar@suse.cz
- update to 0.4.5
  * bugfixes
  * new MIBs
- drop libsmi-0.4.5-sysconf.diff, included upstream
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jun 13 2005 ro@suse.de
- do not redefine vsnprintf
* Thu Feb 24 2005 mjancar@suse.cz
- update to 0.4.3
* Fri Feb 27 2004 mjancar@suse.cz
- update to 0.4.2
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Thu Jul 31 2003 mjancar@suse.cz
- use %%run_ldconfig
* Thu May 29 2003 mjancar@suse.cz
- update to 0.4.1
* Wed May 28 2003 coolo@suse.de
- add the aclocal macro file to the devel package
* Fri May  9 2003 ro@suse.de
- do a full autoreconf
* Tue Jan 29 2002 cihlar@suse.cz
- use %%{_libdir}
* Mon Nov 26 2001 cihlar@suse.cz
- update to version 0.3.0:
  * many fixes
  * added several files to mibs/... by new RFCs
- devel subpackage created
* Mon Nov 12 2001 cihlar@suse.cz
- fixed installation with new automake
* Wed Jun  6 2001 cihlar@suse.cz
- fixed to compile with new libtool
* Tue Apr 17 2001 cihlar@suse.cz
- update to version 0.2.16
* Wed Mar  7 2001 cihlar@suse.cz
- update to version 0.2.14
* Tue Feb 27 2001 cihlar@suse.cz
- update to version 0.2.13
- compile with --enable-smi and --enable-sming
* Sun Dec  3 2000 smid@suse.cz
- new version 0.2.11
* Wed Oct 11 2000 smid@suse.cz
- new version 0.2.6
* Thu Jun  8 2000 cihlar@suse.cz
- fixed License tag
- added %%clean
* Fri Apr 21 2000 smid@suse.cz
- upgrade to 0.2.0
- buildroot added
* Sat Apr  8 2000 bk@suse.de
- added suse update config macro
* Thu Mar  2 2000 uli@suse.de
- moved man pages to %%{_mandir}
* Mon Oct 25 1999 uli@suse.de
- update -> 0.1.7
* Mon Sep 27 1999 uli@suse.de
- new package, version 0.1.6
